\name{levelplot}
\alias{levelplot}
\title{Create a level plot}
\usage{
levelplot(x, y, z, xlim = range(x, finite = TRUE), ylim = range(y, finite =
  TRUE), zlim = range(z, finite = TRUE), asp = NA, levels = pretty(zlim,
  nlevels), nlevels = 7, col = cm.colors, ...)
}
\arguments{
  \item{x}{Vector of x-ordinates, length \code{m}}

  \item{y}{Vector of y-ordinates, length \code{n}}

  \item{z}{Matrix of z-values, dimension \code{m} by
  \code{n}}

  \item{xlim}{Range of x-ordinates}

  \item{ylim}{Range of y-ordinates}

  \item{zlim}{Range for colours (white outside this range)}

  \item{asp}{Aspect ratio}

  \item{levels}{Contour values}

  \item{nlevels}{Number of levels (approximately)}

  \item{col}{Colours, or colour palette}

  \item{...}{Additional arguments to \code{\link{contour}}}
}
\description{
A level plot is a 2D filled contour plot.  \code{levelplot}
uses \code{\link{.filled.contour}} to create a colour
field, and then overlays contours on it using
\code{\link{contour}}.  It does not do any annotations,
which can be added afterwards: see Examples.
}
\examples{
x <- seq(from = -2, to = 5, length = 101)
y <- seq(from = -2, to = 5, length = 101)
grid <- expand.grid(x = x, y = y)
z <- apply(as.matrix(grid), 1, banana, theta = 100)
dim(z) <- c(length(x), length(y))

foo <- levelplot(x, y, log(z), asp = 1, lwd = 2, labcex = 0.7)

## now anotate

title(xlab = "X values", ylab = "Y values",
      main = "Rosenbrock banana function")
axis(1, pos = foo$ylim[1])
axis(2, pos = foo$xlim[1], las = 1)
}
\seealso{
\code{\link{filled.contour}}, which uses a separate colour
scale rather than superimposing contours with value label.
}

